################################################################################
#This is the script for replicating the analysis presented in "What's a dog
#story worth?"
#
#See the README.txt file for descriptions of the variables used in this 
#analysis.
################################################################################

rm(list=ls())
require(msm)
require(sandwich)
require(MASS)
setwd("C:\\Dogs Article")

nyt <- read.table("DogsDataTable.txt",sep="\t",header=T,stringsAsFactors=F)

################################################################################
#Analysis
################################################################################

#Poisson Regression Presented in Table 3
summary(pm1 <- glm(MinorPaperCount ~ IsDogStory + ProminenceScore + WordCount.as.share.median + as.factor(date.key),data=nyt, family = "poisson"))

#Robustness check: 
#Omit cases involving Katrina shelters and the Supreme Court
#(these cases were identified as potentially special by a PS reviewer)
special.case.dates <- c("11-29-2000","1-25-2005","4-5-2005","9-8-2005","11-1-2012")
nyt$special.case <- ifelse(is.na(match(nyt$date.key,special.case.dates))==F,1,0)
summary(pm2 <- glm(auto.minor.score ~ IsDogStory + ProminenceScore + WordCount.as.share.median + as.factor(date.key),data=nyt,subset=special.case==0,family = "poisson"))

#Robustness check: 
#Poisson regression analysis of story dispersion based on automated content coding
summary(pm3 <- glm(auto.minor.score ~ IsDogStory + ProminenceScore + WordCount.as.share.median + as.factor(date.key),data=nyt, family = "poisson"))

#Alternative model specification: Negative Binomial
summary(glm.nb(MinorPaperCount ~ IsDogStory + ProminenceScore + WordCount.as.share.median + as.factor(date.key),data=nyt))
#summary(glm.nb(MinorPaperCount ~ IsDogStory + I(log(ProminenceScore+.03)) + I(log(WordCount.as.share.median)) + as.factor(date.key),data=nyt))
summary(glm.nb(auto.minor.score ~ IsDogStory + ProminenceScore + WordCount.as.share.median + as.factor(date.key),data=nyt))
#summary(glm.nb(auto.minor.score ~ IsDogStory + I(log(ProminenceScore+.03)) + I(log(WordCount.as.share.median)) + as.factor(date.key),data=nyt))

################################################################################
#Calculate the Incident Rate Ratio Coefficients
################################################################################

cov.pm1 <- vcovHC(pm1, type = "HC0")
std.err.pm1 <- sqrt(diag(cov.pm1))
r.est.pm1 <- cbind(Estimate = coef(pm1), `Robust SE` = std.err.pm1, `Pr(>|z|)` = 2 * 
    pnorm(abs(coef(pm1)/std.err.pm1), lower.tail = FALSE), LL = coef(pm1) - 1.96 * 
    std.err.pm1, UL = coef(pm1) + 1.96 * std.err.pm1)
s1 <- deltamethod(list(~exp(x1), ~exp(x2), ~exp(x3), ~exp(x4), ~exp(x5), ~exp(x6), ~exp(x7), ~exp(x8), ~exp(x9), ~exp(x10), ~exp(x11), ~exp(x12), ~exp(x13), ~exp(x14), ~exp(x15), ~exp(x16), ~exp(x17), ~exp(x18), ~exp(x19), ~exp(x20), ~exp(x21)),
                  coef(pm1), cov.pm1)
## exponentiate old estimates dropping the p values
rexp.est.pm1 <- exp(r.est.pm1[, -3])
## replace SEs with estimates for exponentiated coefficients
rexp.est.pm1[, "Robust SE"] <- s1
rexp.est.pm1

